<?php

/**
 * [XenCustomize] Limit Resource Downloads
 * Product Page: https://xencustomize.com/product/limit-resource-downloads/
 * Copyright © 2023 XenCustomize.com. All Rights Reserved.
 *
 * @license Agreement: https://xencustomize.com/license-agreement/
 */

/******************************************************************************************/

namespace XenCustomize\LimitResourceDownloads;

use XF\AddOn\AbstractSetup;
use XF\AddOn\StepRunnerInstallTrait;
use XF\AddOn\StepRunnerUninstallTrait;
use XF\AddOn\StepRunnerUpgradeTrait;
use XF\Db\Schema\Alter;
use XF\Db\Schema\Create;

class Setup extends AbstractSetup
{
	use StepRunnerInstallTrait;
	use StepRunnerUpgradeTrait;
	use StepRunnerUninstallTrait;

    // ############################################ POST INSTALL STEPS #########################
    
    public function postInstall(array &$stateChanges)
    {
        if ($this->applyDefaultPermissions())
        {
            $this->app->jobManager()->enqueueUnique(
                'permissionRebuild',
                'XF:PermissionRebuild',
                [],
                false
            );
        }
    }

    protected function applyDefaultPermissions($previousVersion = null)
    {
        $applied = false;
    
        if (!$previousVersion)
        {
            $this->applyGlobalPermission('resource', 'reactionLimit', 'resource', 'react');
            $this->applyGlobalPermission('resource', 'bypassReactionLimit', 'general', 'bypassFloodCheck');
            $this->applyGlobalPermission('resource', 'bypassMessageCountLimit', 'general', 'bypassFloodCheck');
            $this->applyGlobalPermission('xcuLimitResourceDownloads', 'changeReaction', 'resource', 'download');
            $this->applyGlobalPermission('xcuLimitResourceDownloads', 'undoReaction', 'resource', 'download');
    
            $applied = true;
        }

        return $applied;
    }

    // ############################################ POST UPGRADE STEPS #########################
    
    public function postUpgrade($previousVersion, array &$stateChanges)
    {
        if ($previousVersion < 1010032) {
            $this->applyGlobalPermission('xcuLimitResourceDownloads', 'changeReaction', 'resource', 'download');
            $this->applyGlobalPermission('xcuLimitResourceDownloads', 'undoReaction', 'resource', 'download');
    
            $this->app->jobManager()->enqueueUnique(
                'permissionRebuild',
                'XF:PermissionRebuild',
                [],
                false
            );
        }
    }
}