<?php

/**
 * [XenCustomize] Limit Resource Downloads
 * Product Page: https://xencustomize.com/product/limit-resource-downloads/
 * Copyright © 2023 XenCustomize.com. All Rights Reserved.
 *
 * @license Agreement: https://xencustomize.com/license-agreement/
 */

/******************************************************************************************/

namespace XenCustomize\LimitResourceDownloads\XF\Option;

class PositiveReactionIDs extends \XF\Option\AbstractOption
{
    // Render the custom option control in the admin panel
    public static function renderOption(\XF\Entity\Option $option, array $htmlParams)
    {
        // Initialize an empty array to hold choices
        $choices = [];

        // Iterate through each ID in the option's value
        foreach ($option->option_value as $id)
        {
            // Check if the ID is a positive integer
            if (filter_var($id, FILTER_VALIDATE_INT, ['options' => ['min_range' => 1]]))
            {
                // Add it to the choices array
                $choices[] = [
                    'id' => intval($id),
                ];
            }
        }

        // Return the rendered template with the choices and counter
        return self::getTemplate('admin:xcu_lrdl_positive_reaction_ids', $option, $htmlParams, [
            'choices' => $choices,
            'nextCounter' => count($choices)
        ]);
    }

    // Verify and sanitize the option's value
    public static function verifyOption(array &$value)
    {
        $output = [];

        // Iterate through each entry in the value array
        foreach ($value as $entry)
        {
            // Check if the 'id' key is set and is a positive integer
            if (isset($entry['id']) && filter_var($entry['id'], FILTER_VALIDATE_INT, ['options' => ['min_range' => 1]]))
            {
                // Add the sanitized ID to the output array
                $output[] = intval($entry['id']);
            }
        }

        // Update the value array with the sanitized output
        $value = $output;

        // Return true to indicate successful verification
        return true;
    }
}
